*******************
imreduc
*******************

overview
=============

imreduc is a set of tools to reduce/process FITS imagery for both photography and astronomical research purposes.

imreduc supports border masking, removal of flats and bias', estimation of overall sky values, image series arithmetic, and sum based image stacking.

Reference/API
=============

.. automodapi:: dorado.imreduc